<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Category関連API
 *
 * Category関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: CategoryAPI.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 */

/**
 * WordPress XML-RPC Category関連API
 *
 * Category関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 *
 */
class WordPress_Core_CategoryAPI extends WordPress_API
{
   /**
    * カテゴリ一覧の取得
    *
    * @return array カテゴリ一覧。失敗時はfalse
    */
    function getCategories()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getCategories', $params);

        return $this->request($request);
    }

   /**
    * カテゴリの作成
    *
    * @param array $category カテゴリ情報
    * @return integer カテゴリID。失敗時はfalse
    */
    function newCategory($category)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $category
        );

        $request = $this->buildRequest('wp.newCategory', $params);

        return $this->request($request);
    }
    
   /**
    * カテゴリの削除
    *
    * @param integer $category_id カテゴリID
    * @return bool true:成功,false:失敗
    */
    function deleteCategory($category_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $category_id
        );

        $request = $this->buildRequest('wp.deleteCategory', $params);

        return $this->request($request);
    }

   /**
    * カテゴリの検索
    *
    * @param string $category 検索文字列
    * @param integer $max_results 取得結果数
    * @return array カテゴリ情報。失敗時はfalse
    */
    function suggestCategories($category, $max_results)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $category,
            $max_results
        );

        $request = $this->buildRequest('wp.suggestCategories', $params);

        return $this->request($request);
    }
}
