<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Comment関連API
 *
 * Comment関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: CommentAPI.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 */

/**
 * WordPress XML-RPC Comment関連API
 *
 * Comment関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 *
 */
class WordPress_Core_CommentAPI extends WordPress_API
{
   /**
    * 特定記事のコメント取得
    *
    * @param array $comment コメントが属する記事などの情報
    * @return array コメント情報。失敗時はfalse
    */
    function getComments($comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment
        );

        $request = $this->buildRequest('wp.getComments', $params);

        return $this->request($request);
    }

   /**
    * コメント情報の取得
    *
    * @param integer $comment_id コメントID
    * @return array コメント情報。失敗時はfalse
    */
    function getComment($comment_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id
        );

        $request = $this->buildRequest('wp.getComment', $params);

        return $this->request($request);
    }

   /**
    * 記事のコメント数を取得
    *
    * @param integer $post_id 記事ID
    * @return integer 記事のコメント数。失敗時はfalse
    */
    function getCommentCount($post_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $post_id
        );

        $request = $this->buildRequest('wp.getCommentCount', $params);

        return $this->request($request);
    }

   /**
    * コメント用ステータス一覧の取得
    *
    * @return array コメント用ステータス一覧。失敗時はfalse
    */
    function getCommentStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getCommentStatusList', $params);
        return $this->request($request);
    }

   /**
    * コメント作成
    *
    * @param integer $post_id 記事ID
    * @param array $comment コメント情報
    * @return integer コメントID。失敗時はfalse
    */
    function newComment($post_id, $comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $post_id,
            $comment
        );

        $request = $this->buildRequest('wp.newComment', $params);

        return $this->request($request);
    }

   /**
    * コメント編集
    *
    * @param integer $comment_id コメントID
    * @param array $comment コメント情報
    * @return integer コメントID。失敗時はfalse
    */
    function editComment($comment_id, $comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id,
            $comment
        );

        $request = $this->buildRequest('wp.editComment', $params);

        return $this->request($request);
    }
    
   /**
    * コメント削除
    *
    * @param integer $comment_id コメントID
    * @return bool true:成功,false:失敗
    */
    function deleteComment($comment_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id
        );

        $request = $this->buildRequest('wp.deleteComment', $params);

        return $this->request($request);
    }
}
