<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC 文字コード関連処理
 *
 * 文字コード関連処理を集めたクラス
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: Encode.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 */

/**
 * WordPress XML-RPC 文字コード関連処理
 *
 * 文字コード関連処理を集めたクラス
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 *
 */

abstract class WordPress_Core_Encode
{
    const Utf8 = 'UTF-8';
    const ShiftJis = 'Shift_JIS';
    const EucJp = 'EUC-JP';
    const HtmlEntities = 'HTML-ENTITIES';

   /**
    * 使用可能な文字コード一覧を返す
    *
    * @return array 使用可能な文字コード一覧
    */
    protected function getEncodeList()
    {
        return array(
            self::Utf8 => true,
            self::ShiftJis => true,
            self::EucJp => true,
            self::HtmlEntities => true
        );
    }

   /**
    * 使用可能な文字コードかどうかチェック
    *
    * @param string $encode 文字コード名
    * @return bool true:正当, false:不正
    */
    static function isValidEncode($encode)
    {
        $encode_list = self::getEncodeList();
        if (!isset($encode_list[$encode])) return false;
        if (!$encode_list[$encode]) return false;
        return true;
    }

   /**
    * 文字コード変換
    *
    * @param mixed $params 文字コード変換したい配列 or 変数
    * @param string $to_encode 変換先エンコード名
    * @param string $from_encode 変換元エンコード名
    * @return mixed $params 文字コード変換された配列 or 変数
    */
    static function encode($params, $to_encode, $from_encode)
    {
        if (!is_array($params)) {
            return mb_convert_encoding($params, $to_encode, $from_encode);
        } else {
            foreach ($params as $key => $param) {
                $params[$key] = self::encode($param, $to_encode, $from_encode);
            }
            return $params;
        }
    }
}
