<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Page関連API
 *
 * Page関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: PageAPI.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 */

/**
 * WordPress XML-RPC Page関連API
 *
 * Page関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://codex.wordpress.org/XML-RPC_wp
 *
 */
class WordPress_Core_PageAPI extends WordPress_API
{
   /**
    * ページ一覧の取得
    *
    * @return array ページ一覧。失敗時はfalse
    */
    function getPages()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPages', $params);

        return $this->request($request);
    }

   /**
    * ページの取得
    *
    * @param integer $page_id ページID
    * @return array ページ情報。失敗時はfalse
    */
    function getPage($page_id)
    {
        $params = array(
            $this->config->blogId(),
            $page_id,
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPage', $params);

        return $this->request($request);
    }

   /**
    * ページ一覧の取得(簡易版)
    *
    * @return array ページ一覧(簡易版)。失敗時はfalse
    */
    function getPageList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageList', $params);

        return $this->request($request);
    }

   /**
    * ページの作成
    *
    * @param array $content ページ情報
    * @return integer ページID。失敗時はfalse
    */
    function newPage($content)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $content
        );

        $request = $this->buildRequest('wp.newPage', $params);

        return $this->request($request);
    }

   /**
    * ページの編集
    *
    * @param integer $page_id ページID
    * @param array $content ページ情報
    * @return bool true:成功,false:失敗
    */
    function editPage($page_id, $content)
    {
        $params = array(
            $this->config->blogId(),
            $page_id,
            $this->config->username(),
            $this->config->password(),
            $content
        );

        $request = $this->buildRequest('wp.editPage', $params);

        return $this->request($request);
    }

   /**
    * ページの削除
    *
    * @param integer $page_id ページID
    * @return bool true:成功,false:失敗
    */
    function deletePage($page_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $page_id
        );

        $request = $this->buildRequest('wp.deletePage', $params);

        return $this->request($request);
    }

   /**
    * ページ状態一覧の取得
    *
    * @return array ページ状態一覧。失敗時はfalse
    */
    function getPageStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageStatusList', $params);

        return $this->request($request);
    }

   /**
    * ページテンプレート情報の取得
    *
    * @return array ページテンプレート情報。失敗時はfalse
    */
    function getPageTemplates()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageTemplates', $params);

        return $this->request($request);
    }
}
