<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Post関連API
 *
 * Post関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: PostAPI.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://www.na.rim.or.jp/~tsupo/program/blogTool/mt_xmlRpc.html#w01
 */

/**
 * WordPress XML-RPC Post関連API
 *
 * Post関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @see       http://www.na.rim.or.jp/~tsupo/program/blogTool/mt_xmlRpc.html#w01
 *
 */
class WordPress_Core_PostAPI extends WordPress_API
{
   /**
    * 新規記事の投稿
    *
    * @param array $content 記事の内容
    * @param integer $publish 公開フラグ(1:公開,0:下書き)
    * @return string 新規記事ID。失敗時はfalse
    */
    function newPost($content, $publish)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $content,
            $publish
        );

        $request = $this->buildRequest('metaWeblog.newPost', $params);

        return $this->request($request);
    }

   /**
    * 記事の編集
    *
    * @param integer $post_id 記事ID
    * @param array $content 記事の内容
    * @param integer $publish 公開フラグ(1:公開,0:下書き)
    * @return bool true:成功,false:失敗
    */
    function editPost($post_id, $content, $publish)
    {
        $params = array(
            $post_id,
            $this->config->username(),
            $this->config->password(),
            $content,
            $publish
        );

        $request = $this->buildRequest('metaWeblog.editPost', $params);

        return $this->request($request);
    }

   /**
    * 記事の取得
    *
    * @param integer $post_id 記事ID
    * @return array 記事情報。失敗時はfalse
    */
    function getPost($post_id)
    {
        $params = array(
            $post_id,
            $this->config->username(),
            $this->config->password()
        );

        $request = $this->buildRequest('metaWeblog.getPost', $params);

        return $this->request($request);
    }

   /**
    * 最新記事の取得
    *
    * @param integer $max_results 取得数
    * @return array 記事情報一覧。失敗時はfalse
    */
    function getRecentPosts($max_results)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $max_results
        );

        $request = $this->buildRequest('metaWeblog.getRecentPosts', $params);

        return $this->request($request);
    }

   /**
    * 最新記事のタイトル取得
    *
    * @param integer $max_results 取得数
    * @return array 記事情報タイトル一覧。失敗時はfalse
    */
    function getRecentPostTitles($max_results)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $max_results
        );

        $request = $this->buildRequest('mt.getRecentPostTitles', $params);

        return $this->request($request);
    }

   /**
    * 記事状態一覧の取得
    *
    * @return array 記事状態一覧。失敗時はfalse
    */
    function getPostStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPostStatusList', $params);

        return $this->request($request);
    }
}
