<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC ユーティリティ
 *
 * WordPress XML-RPC APIのユーティリティ
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id: Util.class.php 6 2009-10-03 18:41:22Z taka0125 $
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 */

/**
 * WordPress XML-RPC ユーティリティ
 *
 * WordPress XML-RPC APIのユーティリティ
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 *
 */
abstract class WordPress_Core_Util
{
   /**
    * lowerキャメルケースへの変換
    *
    * @param string $string 変換元
    * @return string lowerキャメルケースへ変換された文字列
    */
    static function lowerCamel($string)
    {
        return strtolower(substr($string, 0, 1)) . substr(self::upperCamel($string), 1);
    }

   /**
    * upperキャメルケースへの変換
    *
    * @param string $string 変換元
    * @return string upperキャメルケースへ変換された文字列
    */
    static function upperCamel($string)
    {
        $string = str_replace('_', ' ', strtolower($string));
        $string = str_replace(' ', '', ucwords($string));
        return $string;
    }

   /**
    * アンダースコア形式への変換
    *
    * @param string $string 変換元
    * @return string アンダースコア形式へ変換された文字列
    */
    static function underScore($string)
    {
        $string = strtolower(preg_replace('/([a-z])([A-Z])/', "$1_$2", $string));
        return $string;
    }

   /**
    * datetime用XMLの作成
    *
    * @param integer $timestamp タイムスタンプデータ
    * @return string datetime用XML
    */
    static function createDateTime($timestamp)
    {
        $timestamp = date('c', $timestamp);
        xmlrpc_set_type($timestamp, 'datetime');
        return $timestamp;
    }

   /**
    * base64用XMLの作成
    *
    * @param string $file_path base64へ変換したいファイルのパス
    * @return string base64用XMLの作成
    */
    static function createBase64($file_path)
    {
        $data = file_get_contents($file_path);
        xmlrpc_set_type($data, 'base64');
        return $data;
    }
}
